@@ -90,6 +90,6 @@ def iterate(f: flow.Flow) -> TEventGenerator:
     try:
         e = _iterate_map[type(f)]
     except KeyError as err:
-        raise TypeError("Unknown flow type: {}".format(f)) from err
+        raise TypeError(f"Unknown flow type: {f}") from err
     else:
         yield from e(f)
