@@ -1,50 +1,25 @@
 import time
-from email.utils import parsedate_tz, formatdate, mktime_tz
-from mitmproxy.utils import human
-from mitmproxy.coretypes import multidict
-from mitmproxy.net.http import cookies
-from mitmproxy.net.http import headers as nheaders
-from mitmproxy.net.http import message
-from mitmproxy.net.http import status_codes
-from mitmproxy.utils import strutils
-from typing import AnyStr
-from typing import Dict
+from dataclasses import dataclass
+from email.utils import formatdate, mktime_tz, parsedate_tz
+from typing import Mapping
 from typing import Iterable
+from typing import Optional
 from typing import Tuple
 from typing import Union
 
+from mitmproxy.coretypes import multidict
+from mitmproxy.net.http import cookies, message
+from mitmproxy.net.http import status_codes
+from mitmproxy.net.http.headers import Headers
+from mitmproxy.utils import human
+from mitmproxy.utils import strutils
+from mitmproxy.utils.strutils import always_bytes
 
+
+@dataclass
 class ResponseData(message.MessageData):
-    def __init__(
-        self,
-        http_version,
-        status_code,
-        reason=None,
-        headers=(),
-        content=None,
-        trailers=None,
-        timestamp_start=None,
-        timestamp_end=None
-    ):
-        if isinstance(http_version, str):
-            http_version = http_version.encode("ascii", "strict")
-        if isinstance(reason, str):
-            reason = reason.encode("ascii", "strict")
-        if not isinstance(headers, nheaders.Headers):
-            headers = nheaders.Headers(headers)
-        if isinstance(content, str):
-            raise ValueError("Content must be bytes, not {}".format(type(content).__name__))
-        if trailers is not None and not isinstance(trailers, nheaders.Headers):
-            trailers = nheaders.Headers(trailers)
-
-        self.http_version = http_version
-        self.status_code = status_code
-        self.reason = reason
-        self.headers = headers
-        self.content = content
-        self.trailers = trailers
-        self.timestamp_start = timestamp_start
-        self.timestamp_end = timestamp_end
+    status_code: int
+    reason: bytes
 
 
 class Response(message.Message):
@@ -53,91 +28,119 @@ class Response(message.Message):
     """
     data: ResponseData
 
-    def __init__(self, *args, **kwargs):
-        super().__init__()
-        self.data = ResponseData(*args, **kwargs)
+    def __init__(
+            self,
+            http_version: bytes,
+            status_code: int,
+            reason: bytes,
+            headers: Union[Headers, Tuple[Tuple[bytes, bytes], ...]],
+            content: Optional[bytes],
+            trailers: Union[None, Headers, Tuple[Tuple[bytes, bytes], ...]],
+            timestamp_start: float,
+            timestamp_end: Optional[float],
+    ):
+        # auto-convert invalid types to retain compatibility with older code.
+        if isinstance(http_version, str):
+            http_version = http_version.encode("ascii", "strict")
+        if isinstance(reason, str):
+            reason = reason.encode("ascii", "strict")
 
-    def __repr__(self):
+        if isinstance(content, str):
+            raise ValueError("Content must be bytes, not {}".format(type(content).__name__))
+        if not isinstance(headers, Headers):
+            headers = Headers(headers)
+        if trailers is not None and not isinstance(trailers, Headers):
+            trailers = Headers(trailers)
+
+        self.data = ResponseData(
+            http_version=http_version,
+            status_code=status_code,
+            reason=reason,
+            headers=headers,
+            content=content,
+            trailers=trailers,
+            timestamp_start=timestamp_start,
+            timestamp_end=timestamp_end,
+        )
+
+    def __repr__(self) -> str:
         if self.raw_content:
-            details = "{}, {}".format(
-                self.headers.get("content-type", "unknown content type"),
-                human.pretty_size(len(self.raw_content))
-            )
+            ct = self.headers.get("content-type", "unknown content type")
+            size = human.pretty_size(len(self.raw_content))
+            details = f"{ct}, {size}"
         else:
             details = "no content"
-        return "Response({status_code} {reason}, {details})".format(
-            status_code=self.status_code,
-            reason=self.reason,
-            details=details
-        )
+        return f"Response({self.status_code}, {details})"
 
     @classmethod
     def make(
             cls,
-            status_code: int=200,
-            content: Union[bytes, str]=b"",
-            headers: Union[Dict[str, AnyStr], Iterable[Tuple[bytes, bytes]]]=()
-    ):
+            status_code: int = 200,
+            content: Union[bytes, str] = b"",
+            headers: Union[Headers, Mapping[str, Union[str, bytes]], Iterable[Tuple[bytes, bytes]]] = ()
+    ) -> "Response":
         """
         Simplified API for creating response objects.
         """
-        resp = cls(
-            b"HTTP/1.1",
-            status_code,
-            status_codes.RESPONSES.get(status_code, "").encode(),
-            (),
-            None
-        )
-
-        # Headers can be list or dict, we differentiate here.
-        if isinstance(headers, dict):
-            resp.headers = nheaders.Headers(**headers)
+        if isinstance(headers, Headers):
+            headers = headers
+        elif isinstance(headers, dict):
+            headers = Headers(
+                (always_bytes(k, "utf-8", "surrogateescape"),
+                 always_bytes(v, "utf-8", "surrogateescape"))
+                for k, v in headers.items()
+            )
         elif isinstance(headers, Iterable):
-            resp.headers = nheaders.Headers(headers)
+            headers = Headers(headers)
         else:
             raise TypeError("Expected headers to be an iterable or dict, but is {}.".format(
                 type(headers).__name__
             ))
 
+        resp = cls(
+            b"HTTP/1.1",
+            status_code,
+            status_codes.RESPONSES.get(status_code, "").encode(),
+            headers,
+            None,
+            None,
+            time.time(),
+            time.time(),
+        )
+
         # Assign this manually to update the content-length header.
         if isinstance(content, bytes):
             resp.content = content
         elif isinstance(content, str):
             resp.text = content
         else:
-            raise TypeError("Expected content to be str or bytes, but is {}.".format(
-                type(content).__name__
-            ))
+            raise TypeError(f"Expected content to be str or bytes, but is {type(content).__name__}.")
 
         return resp
 
     @property
-    def status_code(self):
+    def status_code(self) -> int:
         """
         HTTP Status Code, e.g. ``200``.
         """
         return self.data.status_code
 
     @status_code.setter
-    def status_code(self, status_code):
+    def status_code(self, status_code: int) -> None:
         self.data.status_code = status_code
 
     @property
-    def reason(self):
+    def reason(self) -> str:
         """
         HTTP Reason Phrase, e.g. "Not Found".
-        HTTP2 responses do not contain a reason phrase and self.data.reason will be :py:obj:`None`.
-        When :py:obj:`None` return an empty reason phrase so that functions expecting a string work properly.
+        HTTP/2 responses do not contain a reason phrase, an empty string will be returned instead.
         """
         # Encoding: http://stackoverflow.com/a/16674906/934719
-        if self.data.reason is not None:
-            return self.data.reason.decode("ISO-8859-1", "surrogateescape")
-        else:
-            return ""
+        return self.data.reason.decode("ISO-8859-1")
 
     @reason.setter
-    def reason(self, reason):
-        self.data.reason = strutils.always_bytes(reason, "ISO-8859-1", "surrogateescape")
+    def reason(self, reason: Union[str, bytes]) -> None:
+        self.data.reason = strutils.always_bytes(reason, "ISO-8859-1")
 
     def _get_cookies(self):
         h = self.headers.get_all("set-cookie")
