@@ -20,7 +20,7 @@ from mitmproxy.coretypes import basethread
 socket_fileobject = socket.SocketIO
 
 # workaround for https://bugs.python.org/issue29515
-# Python 3.6 for Windows is missing a constant
+# Python 3.8 for Windows is missing a constant, fixed in 3.9
 IPPROTO_IPV6 = getattr(socket, "IPPROTO_IPV6", 41)
 
 
@@ -80,7 +80,7 @@ class Writer(_FileLike):
         if hasattr(self.o, "flush"):
             try:
                 self.o.flush()
-            except (socket.error, IOError) as v:
+            except OSError as v:
                 raise exceptions.TcpDisconnect(str(v))
 
     def write(self, v):
@@ -97,7 +97,7 @@ class Writer(_FileLike):
                     r = self.o.write(v)
                     self.add_log(v[:r])
                     return r
-            except (SSL.Error, socket.error) as e:
+            except (SSL.Error, OSError) as e:
                 raise exceptions.TcpDisconnect(str(e))
 
 
@@ -134,7 +134,7 @@ class Reader(_FileLike):
                     raise exceptions.TcpTimeout()
             except socket.timeout:
                 raise exceptions.TcpTimeout()
-            except socket.error as e:
+            except OSError as e:
                 raise exceptions.TcpDisconnect(str(e))
             except SSL.SysCallError as e:
                 if e.args == (-1, 'Unexpected EOF'):
@@ -178,7 +178,7 @@ class Reader(_FileLike):
                 raise exceptions.TcpDisconnect()
             else:
                 raise exceptions.TcpReadIncomplete(
-                    "Expected %s bytes, got %s" % (length, len(result))
+                    "Expected {} bytes, got {}".format(length, len(result))
                 )
         return result
 
@@ -197,7 +197,7 @@ class Reader(_FileLike):
         if isinstance(self.o, socket_fileobject):
             try:
                 return self.o._sock.recv(length, socket.MSG_PEEK)
-            except socket.error as e:
+            except OSError as e:
                 raise exceptions.TcpException(repr(e))
         elif isinstance(self.o, SSL.Connection):
             try:
@@ -268,7 +268,7 @@ def close_socket(sock):
         # Now we can close the other half as well.
         sock.shutdown(socket.SHUT_RD)
 
-    except socket.error:
+    except OSError:
         pass
 
     sock.close()
@@ -442,7 +442,7 @@ class TCPClient(_Connection):
                 sock.connect(sa)
                 return sock
 
-            except socket.error as _:
+            except OSError as _:
                 err = _
                 if sock is not None:
                     sock.close()
@@ -450,12 +450,12 @@ class TCPClient(_Connection):
         if err is not None:
             raise err
         else:
-            raise socket.error("getaddrinfo returns an empty list")  # pragma: no cover
+            raise OSError("getaddrinfo returns an empty list")  # pragma: no cover
 
     def connect(self):
         try:
             connection = self.create_connection()
-        except (socket.error, IOError) as err:
+        except OSError as err:
             raise exceptions.TcpException(
                 'Error connecting to "%s": %s' %
                 (self.address[0], err)
@@ -555,7 +555,7 @@ class TCPServer:
         self.__shutdown_request = False
 
         if self.address[0] == 'localhost':
-            raise socket.error("Binding to 'localhost' is prohibited. Please use '::1' or '127.0.0.1' directly.")
+            raise OSError("Binding to 'localhost' is prohibited. Please use '::1' or '127.0.0.1' directly.")
 
         self.socket = None
 
@@ -568,7 +568,7 @@ class TCPServer:
             self.socket.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
             self.socket.setsockopt(IPPROTO_IPV6, socket.IPV6_V6ONLY, 0)
             self.socket.bind(self.address)
-        except socket.error:
+        except OSError:
             if self.socket:
                 self.socket.close()
             self.socket = None
@@ -580,7 +580,7 @@ class TCPServer:
                 self.socket.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
                 self.socket.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
                 self.socket.bind(self.address)
-            except socket.error:
+            except OSError:
                 if self.socket:
                     self.socket.close()
                 self.socket = None
@@ -620,7 +620,7 @@ class TCPServer:
                 if self.socket in r:
                     connection, client_address = self.socket.accept()
                     t = basethread.BaseThread(
-                        "TCPConnectionHandler (%s: %s:%s -> %s:%s)" % (
+                        "TCPConnectionHandler ({}: {}:{} -> {}:{})".format(
                             self.__class__.__name__,
                             client_address[0],
                             client_address[1],
@@ -654,11 +654,11 @@ class TCPServer:
         # none.
         if traceback:
             exc = str(traceback.format_exc())
-            print(u'-' * 40, file=fp)
+            print('-' * 40, file=fp)
             print(
-                u"Error in processing of request from %s" % repr(client_address), file=fp)
+                "Error in processing of request from %s" % repr(client_address), file=fp)
             print(exc, file=fp)
-            print(u'-' * 40, file=fp)
+            print('-' * 40, file=fp)
 
     def handle_client_connection(self, conn, client_address):  # pragma: no cover
         """
