@@ -2,6 +2,7 @@ import typing
 
 from mitmproxy import exceptions
 from mitmproxy import flow
+from mitmproxy import ctx
 
 from mitmproxy.tools.console import overlay
 from mitmproxy.tools.console import signals
@@ -15,8 +16,8 @@ class CommandExecutor:
         if cmd.strip():
             try:
                 ret = self.master.commands.execute(cmd)
-            except exceptions.CommandError as v:
-                signals.status_message.send(message=str(v))
+            except exceptions.CommandError as e:
+                ctx.log.error(str(e))
             else:
                 if ret:
                     if type(ret) == typing.Sequence[flow.Flow]:
